package Ascii::Text::Font::Speed;
use strict;
use warnings;
use Rope;
use Rope::Autoload;

extends 'Ascii::Text::Font';

property character_height => (
	initable  => 0,
	writeable => 0,
	value     => 6
);

function space => sub {
	my (@character) = $_[0]->default_character(6);
	return \@character;
};

function character_A => sub {
	my @character = $_[0]->default_character(8);
	$character[0][0] = $character[0][1] = $character[0][2] = $character[0][3]
	    = $character[0][4] = $character[0][5] = $character[0][6]
	    = $character[1][0] = $character[1][1] = $character[1][2]
	    = $character[2][0] = $character[2][1] = $character[3][0]
	    = $character[3][3] = $character[3][4] = $character[3][5]
	    = $character[4][1] = $character[4][6] = "_";
	$character[2][4] = $character[4][0] = $character[4][2] = "\/";
	$character[1][7] = $character[2][5] = $character[2][7] = $character[3][7]
	    = $character[4][5] = $character[4][7] = "\|";
	return \@character;
};

function character_B => sub {
	my @character = $_[0]->default_character(9);
	$character[2][8] = "\|";
	$character[1][8] = "\)";
	$character[0][0] = $character[0][1] = $character[0][2] = $character[0][3]
	    = $character[0][4] = $character[0][5] = $character[0][6]
	    = $character[0][7] = $character[1][0] = $character[1][1]
	    = $character[1][2] = $character[1][5] = $character[1][6]
	    = $character[2][0] = $character[2][1] = $character[2][4]
	    = $character[2][5] = $character[3][0] = $character[3][4]
	    = $character[4][1] = $character[4][2] = $character[4][3]
	    = $character[4][4] = $character[4][5] = "_";
	$character[3][3] = $character[3][5] = $character[3][7] = $character[4][0]
	    = $character[4][6] = "\/";
	return \@character;
};

function character_C => sub {
	my @character = $_[0]->default_character(9);
	$character[4][0] = "\\";
	$character[0][0] = $character[0][1] = $character[0][2] = $character[0][3]
	    = $character[0][4] = $character[0][5] = $character[0][6]
	    = $character[0][7] = $character[0][8] = $character[1][0]
	    = $character[1][1] = $character[1][4] = $character[1][5]
	    = $character[1][6] = $character[1][7] = $character[2][0]
	    = $character[3][3] = $character[3][4] = $character[3][5]
	    = $character[4][1] = $character[4][2] = $character[4][3]
	    = $character[4][4] = "_";
	$character[1][8] = $character[2][3] = $character[3][0] = $character[3][2]
	    = $character[4][5] = "\/";
	return \@character;
};

function character_D => sub {
	my @character = $_[0]->default_character(9);
	$character[2][4] = $character[2][6] = $character[2][8] = $character[3][3]
	    = $character[3][5] = $character[3][7] = $character[4][0]
	    = $character[4][6] = "\/";
	$character[0][0] = $character[0][1] = $character[0][2] = $character[0][3]
	    = $character[0][4] = $character[0][5] = $character[0][6]
	    = $character[0][7] = $character[1][0] = $character[1][1]
	    = $character[1][2] = $character[1][5] = $character[1][6]
	    = $character[2][0] = $character[2][1] = $character[3][0]
	    = $character[3][4] = $character[4][1] = $character[4][2]
	    = $character[4][3] = $character[4][4] = $character[4][5] = "_";
	$character[1][8] = "\\";
	return \@character;
};

function character_E => sub {
	my @character = $_[0]->default_character(10);
	$character[1][9] = $character[2][6] = $character[3][3] = $character[4][0]
	    = $character[4][6] = "\/";
	$character[0][0] = $character[0][1] = $character[0][2] = $character[0][3]
	    = $character[0][4] = $character[0][5] = $character[0][6]
	    = $character[0][7] = $character[0][8] = $character[0][9]
	    = $character[1][0] = $character[1][1] = $character[1][2]
	    = $character[1][5] = $character[1][6] = $character[1][7]
	    = $character[1][8] = $character[2][0] = $character[2][1]
	    = $character[2][4] = $character[2][5] = $character[3][0]
	    = $character[3][4] = $character[3][5] = $character[3][6]
	    = $character[4][1] = $character[4][2] = $character[4][3]
	    = $character[4][4] = $character[4][5] = "_";
	return \@character;
};

function character_F => sub {
	my @character = $_[0]->default_character(10);
	$character[1][9] = $character[2][4] = $character[3][5] = $character[4][0]
	    = $character[4][2] = "\/";
	$character[0][0] = $character[0][1] = $character[0][2] = $character[0][3]
	    = $character[0][4] = $character[0][5] = $character[0][6]
	    = $character[0][7] = $character[0][8] = $character[0][9]
	    = $character[1][0] = $character[1][1] = $character[1][2]
	    = $character[1][5] = $character[1][6] = $character[1][7]
	    = $character[1][8] = $character[2][0] = $character[2][1]
	    = $character[2][5] = $character[3][0] = $character[3][3]
	    = $character[3][4] = $character[4][1] = "_";
	return \@character;
};

function character_G => sub {
	my @character = $_[0]->default_character(9);
	$character[4][0] = "\\";
	$character[1][8] = $character[2][3] = $character[3][0] = $character[3][2]
	    = $character[3][4] = $character[3][6] = $character[4][5] = "\/";
	$character[0][0] = $character[0][1] = $character[0][2] = $character[0][3]
	    = $character[0][4] = $character[0][5] = $character[0][6]
	    = $character[0][7] = $character[0][8] = $character[1][0]
	    = $character[1][1] = $character[1][4] = $character[1][5]
	    = $character[1][6] = $character[1][7] = $character[2][0]
	    = $character[2][5] = $character[2][6] = $character[3][3]
	    = $character[4][1] = $character[4][2] = $character[4][3]
	    = $character[4][4] = "_";
	return \@character;
};

function character_H => sub {
	my @character = $_[0]->default_character(10);
	$character[0][0] = $character[0][1] = $character[0][2] = $character[0][3]
	    = $character[0][4] = $character[0][5] = $character[0][8]
	    = $character[0][9] = $character[1][0] = $character[1][1]
	    = $character[1][2] = $character[2][0] = $character[2][1]
	    = $character[2][5] = $character[3][0] = $character[3][3]
	    = $character[3][4] = $character[4][1] = $character[4][5] = "_";
	$character[1][5] = $character[1][7] = $character[1][9] = $character[2][4]
	    = $character[2][6] = $character[2][8] = $character[3][7]
	    = $character[4][0] = $character[4][2] = $character[4][4]
	    = $character[4][6] = "\/";
	return \@character;
};

function character_I => sub {
	my @character = $_[0]->default_character(8);
	$character[0][0] = $character[0][1] = $character[0][2] = $character[0][3]
	    = $character[0][4] = $character[0][5] = $character[0][6]
	    = $character[0][7] = $character[1][0] = $character[1][1]
	    = $character[1][2] = $character[1][3] = $character[1][6]
	    = $character[2][1] = $character[2][2] = $character[3][0]
	    = $character[3][1] = $character[4][1] = $character[4][2]
	    = $character[4][3] = "_";
	$character[1][7] = $character[2][5] = $character[3][2] = $character[3][4]
	    = $character[4][0] = $character[4][4] = "\/";
	return \@character;
};

function character_J => sub {
	my @character = $_[0]->default_character(9);
	$character[4][0] = "\\";
	$character[0][0] = $character[0][1] = $character[0][2] = $character[0][3]
	    = $character[0][4] = $character[0][5] = $character[0][6]
	    = $character[0][7] = $character[0][8] = $character[1][0]
	    = $character[1][1] = $character[1][2] = $character[1][3]
	    = $character[1][4] = $character[1][5] = $character[2][0]
	    = $character[2][1] = $character[2][2] = $character[2][4]
	    = $character[3][3] = $character[4][1] = $character[4][2]
	    = $character[4][3] = $character[4][4] = "_";
	$character[1][8] = $character[2][7] = $character[3][0] = $character[3][2]
	    = $character[3][4] = $character[3][6] = $character[4][5] = "\/";
	return \@character;
};

function character_K => sub {
	my @character = $_[0]->default_character(9);
	$character[3][4] = $character[3][6] = $character[4][4] = $character[4][6]
	    = "\|";
	$character[2][5] = "\<";
	$character[1][5] = $character[1][6] = $character[1][8] = $character[3][3]
	    = $character[4][0] = $character[4][2] = "\/";
	$character[0][0] = $character[0][1] = $character[0][2] = $character[0][3]
	    = $character[0][4] = $character[0][5] = $character[0][7]
	    = $character[0][8] = $character[1][0] = $character[1][1]
	    = $character[1][2] = $character[1][7] = $character[2][0]
	    = $character[2][1] = $character[3][0] = $character[4][1]
	    = $character[4][5] = "_";
	$character[2][4] = "\,";
	return \@character;
};

function character_L => sub {
	my @character = $_[0]->default_character(7);
	$character[1][5] = $character[2][4] = $character[3][3] = $character[4][0]
	    = $character[4][6] = "\/";
	$character[0][0] = $character[0][1] = $character[0][2] = $character[0][3]
	    = $character[0][4] = $character[0][5] = $character[1][0]
	    = $character[1][1] = $character[1][2] = $character[2][0]
	    = $character[2][1] = $character[3][0] = $character[3][4]
	    = $character[3][5] = $character[3][6] = $character[4][1]
	    = $character[4][2] = $character[4][3] = $character[4][4]
	    = $character[4][5] = "_";
	return \@character;
};

function character_M => sub {
	my @character = $_[0]->default_character(11);
	$character[1][6] = $character[2][5]  = "\|";
	$character[1][7] = $character[1][10] = $character[2][4]
	    = $character[2][7] = $character[2][9] = $character[3][3]
	    = $character[3][6] = $character[3][8] = $character[4][0]
	    = $character[4][2] = $character[4][5] = $character[4][7] = "\/";
	$character[0][0] = $character[0][1] = $character[0][2] = $character[0][3]
	    = $character[0][4] = $character[0][5]  = $character[0][8]
	    = $character[0][9] = $character[0][10] = $character[1][0]
	    = $character[1][1] = $character[1][2]  = $character[2][0]
	    = $character[2][1] = $character[2][6]  = $character[3][0]
	    = $character[4][1] = $character[4][6]  = "_";
	return \@character;
};

function character_N => sub {
	my @character = $_[0]->default_character(10);
	$character[1][5] = $character[2][5] = $character[3][4] = $character[4][4]
	    = "\|";
	$character[0][0] = $character[0][1] = $character[0][2] = $character[0][3]
	    = $character[0][4] = $character[0][8] = $character[0][9]
	    = $character[1][0] = $character[1][1] = $character[1][2]
	    = $character[2][0] = $character[2][1] = $character[3][0]
	    = $character[4][1] = $character[4][5] = "_";
	$character[1][7] = $character[1][9] = $character[2][6] = $character[2][8]
	    = $character[3][3] = $character[3][7] = $character[4][0]
	    = $character[4][2] = $character[4][6] = "\/";
	return \@character;
};

function character_O => sub {
	my @character = $_[0]->default_character(8);
	$character[2][3] = $character[2][5] = $character[2][7] = $character[3][0]
	    = $character[3][2] = $character[3][4] = $character[3][6]
	    = $character[4][5] = "\/";
	$character[0][0] = $character[0][1] = $character[0][2] = $character[0][3]
	    = $character[0][4] = $character[0][5] = $character[0][6]
	    = $character[1][0] = $character[1][1] = $character[1][4]
	    = $character[1][5] = $character[2][0] = $character[3][3]
	    = $character[4][1] = $character[4][2] = $character[4][3]
	    = $character[4][4] = "_";
	$character[1][7] = $character[4][0] = "\\";
	return \@character;
};

function character_P => sub {
	my @character = $_[0]->default_character(9);
	$character[1][8] = "\\";
	$character[0][0] = $character[0][1] = $character[0][2] = $character[0][3]
	    = $character[0][4] = $character[0][5] = $character[0][6]
	    = $character[0][7] = $character[1][0] = $character[1][1]
	    = $character[1][2] = $character[1][5] = $character[1][6]
	    = $character[2][0] = $character[2][1] = $character[2][5]
	    = $character[3][0] = $character[3][3] = $character[3][4]
	    = $character[3][5] = $character[3][6] = $character[4][1] = "_";
	$character[2][4] = $character[2][6] = $character[2][8] = $character[3][7]
	    = $character[4][0] = $character[4][2] = "\/";
	return \@character;
};

function character_Q => sub {
	my @character = $_[0]->default_character(8);
	$character[2][3] = $character[2][5] = $character[2][7] = $character[3][0]
	    = $character[3][2] = $character[3][4] = $character[3][6] = "\/";
	$character[0][0] = $character[0][1] = $character[0][2] = $character[0][3]
	    = $character[0][4] = $character[0][5] = $character[0][6]
	    = $character[1][0] = $character[1][1] = $character[1][4]
	    = $character[1][5] = $character[2][0] = $character[3][3]
	    = $character[4][1] = $character[4][2] = $character[4][3]
	    = $character[4][5] = "_";
	$character[1][7] = $character[4][0] = $character[4][4] = $character[4][6]
	    = "\\";
	return \@character;
};

function character_R => sub {
	my @character = $_[0]->default_character(9);
	$character[0][0] = $character[0][1] = $character[0][2] = $character[0][3]
	    = $character[0][4] = $character[0][5] = $character[0][6]
	    = $character[0][7] = $character[1][0] = $character[1][1]
	    = $character[1][2] = $character[1][5] = $character[1][6]
	    = $character[2][0] = $character[2][1] = $character[2][5]
	    = $character[3][0] = $character[3][3] = $character[3][6]
	    = $character[4][1] = $character[4][5] = "_";
	$character[3][4] = "\,";
	$character[2][4] = $character[2][6] = $character[2][8] = $character[3][7]
	    = $character[4][0] = $character[4][2] = "\/";
	$character[4][4] = $character[4][6] = "\|";
	$character[1][8] = "\\";
	return \@character;
};

function character_S => sub {
	my @character = $_[0]->default_character(8);
	$character[2][6] = "\\";
	$character[1][7] = $character[3][4] = $character[3][6] = $character[4][0]
	    = $character[4][5] = "\/";
	$character[0][0] = $character[0][1] = $character[0][2] = $character[0][3]
	    = $character[0][4] = $character[0][5] = $character[0][6]
	    = $character[0][7] = $character[1][0] = $character[1][1]
	    = $character[1][4] = $character[1][5] = $character[1][6]
	    = $character[2][0] = $character[2][1] = $character[2][2]
	    = $character[2][3] = $character[2][4] = $character[3][0]
	    = $character[3][1] = $character[3][2] = $character[3][3]
	    = $character[4][1] = $character[4][2] = $character[4][3]
	    = $character[4][4] = "_";
	return \@character;
};

function character_T => sub {
	my @character = $_[0]->default_character(8);
	$character[1][7] = $character[2][4] = $character[3][3] = $character[4][0]
	    = $character[4][2] = "\/";
	$character[0][0] = $character[0][1] = $character[0][2] = $character[0][3]
	    = $character[0][4] = $character[0][5] = $character[0][6]
	    = $character[0][7] = $character[1][0] = $character[1][1]
	    = $character[1][2] = $character[1][5] = $character[1][6]
	    = $character[2][0] = $character[2][1] = $character[3][0]
	    = $character[4][1] = "_";
	return \@character;
};

function character_U => sub {
	my @character = $_[0]->default_character(9);
	$character[4][0] = "\\";
	$character[0][0] = $character[0][1] = $character[0][2] = $character[0][3]
	    = $character[0][4] = $character[0][7] = $character[0][8]
	    = $character[1][0] = $character[1][1] = $character[2][0]
	    = $character[3][3] = $character[4][1] = $character[4][2]
	    = $character[4][3] = $character[4][4] = "_";
	$character[1][4] = $character[1][6] = $character[1][8] = $character[2][3]
	    = $character[2][5] = $character[2][7] = $character[3][0]
	    = $character[3][2] = $character[3][4] = $character[3][6]
	    = $character[4][5] = "\/";
	return \@character;
};

function character_V => sub {
	my @character = $_[0]->default_character(9);
	$character[1][3] = $character[2][3] = $character[3][3] = "\|";
	$character[0][0] = $character[0][1] = $character[0][2] = $character[0][7]
	    = $character[0][8] = $character[1][0] = $character[1][1]
	    = $character[2][0] = $character[2][1] = $character[3][0]
	    = $character[3][1] = $character[4][0] = $character[4][1]
	    = $character[4][2] = $character[4][3] = $character[4][4] = "_";
	$character[1][6] = $character[1][8] = $character[2][5] = $character[2][7]
	    = $character[3][4] = $character[3][6] = $character[4][5] = "\/";
	return \@character;
};

function character_W => sub {
	my @character = $_[0]->default_character(12);
	$character[0][0] = $character[0][1] = $character[0][2]
	    = $character[0][10] = $character[0][11] = $character[1][0]
	    = $character[1][1]  = $character[2][0]  = $character[2][1]
	    = $character[3][0]  = $character[3][1]  = $character[4][0]
	    = $character[4][1]  = $character[4][2]  = $character[4][3]
	    = $character[4][6]  = $character[4][7]  = "_";
	$character[1][9] = $character[1][11] = $character[2][5]
	    = $character[2][8] = $character[2][10] = $character[3][4]
	    = $character[3][7] = $character[3][9] = $character[4][4]
	    = $character[4][8] = "\/";
	$character[1][3] = $character[2][3] = $character[2][6] = $character[3][3]
	    = $character[3][6] = $character[4][5] = "\|";
	return \@character;
};

function character_X => sub {
	my @character = $_[0]->default_character(8);
	$character[1][4] = $character[3][5] = $character[4][3] = $character[4][5]
	    = "\|";
	$character[0][0] = $character[0][1] = $character[0][2] = $character[0][3]
	    = $character[0][6] = $character[0][7] = $character[1][0]
	    = $character[1][1] = $character[2][0] = $character[2][1]
	    = $character[3][0] = $character[4][1] = $character[4][4] = "_";
	$character[1][5] = $character[1][7] = $character[2][6] = $character[4][0]
	    = $character[4][2] = "\/";
	return \@character;
};

function character_Y => sub {
	my @character = $_[0]->default_character(6);
	$character[1][2] = "\\";
	$character[1][3] = $character[1][5] = $character[2][4] = $character[3][3]
	    = $character[4][0] = $character[4][2] = "\/";
	$character[0][0] = $character[0][1] = $character[0][4] = $character[0][5]
	    = $character[1][0] = $character[2][0] = $character[2][1]
	    = $character[3][0] = $character[4][1] = "_";
	return \@character;
};

function character_Z => sub {
	my @character = $_[0]->default_character(6);
	$character[1][5] = $character[2][4] = $character[3][3] = $character[4][0]
	    = $character[4][5] = "\/";
	$character[0][0] = $character[0][1] = $character[0][2] = $character[0][3]
	    = $character[0][4] = $character[0][5] = $character[1][0]
	    = $character[1][1] = $character[1][2] = $character[2][0]
	    = $character[2][1] = $character[3][0] = $character[3][4]
	    = $character[3][5] = $character[4][1] = $character[4][2]
	    = $character[4][3] = $character[4][4] = "_";
	return \@character;
};

function character_a => sub {
	my @character = $_[0]->default_character(8);
	$character[4][3] = "\,";
	$character[1][0] = $character[1][1] = $character[1][2] = $character[1][3]
	    = $character[1][4] = $character[1][5] = $character[1][7]
	    = $character[2][0] = $character[2][3] = $character[2][4]
	    = $character[3][3] = $character[4][1] = $character[4][2]
	    = $character[4][4] = "_";
	$character[2][7] = $character[3][0] = $character[3][2] = $character[3][4]
	    = $character[3][6] = $character[4][5] = "\/";
	$character[4][0] = "\\";
	$character[2][6] = "\`";
	return \@character;
};

function character_b => sub {
	my @character = $_[0]->default_character(8);
	$character[2][7] = "\\";
	$character[0][0] = $character[0][1] = $character[0][2] = $character[0][3]
	    = $character[0][4] = $character[0][5] = $character[1][0]
	    = $character[1][1] = $character[1][2] = $character[1][6]
	    = $character[2][0] = $character[2][1] = $character[2][4]
	    = $character[2][5] = $character[3][0] = $character[3][4]
	    = $character[4][1] = $character[4][3] = $character[4][4]
	    = $character[4][5] = "_";
	$character[4][2] = "\.";
	$character[1][5] = $character[3][3] = $character[3][5] = $character[3][7]
	    = $character[4][0] = $character[4][6] = "\/";
	return \@character;
};

function character_c => sub {
	my @character = $_[0]->default_character(7);
	$character[2][6] = $character[3][0] = $character[3][2] = $character[4][4]
	    = "\/";
	$character[1][0] = $character[1][1] = $character[1][2] = $character[1][3]
	    = $character[1][4] = $character[1][5] = $character[1][6]
	    = $character[2][0] = $character[2][3] = $character[2][4]
	    = $character[2][5] = $character[3][3] = $character[3][4]
	    = $character[4][1] = $character[4][2] = $character[4][3] = "_";
	$character[4][0] = "\\";
	return \@character;
};

function character_d => sub {
	my @character = $_[0]->default_character(9);
	$character[4][3] = "\,";
	$character[0][0] = $character[0][1] = $character[0][2] = $character[0][3]
	    = $character[0][4] = $character[0][5] = $character[0][6]
	    = $character[0][7] = $character[0][8] = $character[1][0]
	    = $character[1][1] = $character[1][2] = $character[1][3]
	    = $character[1][4] = $character[1][5] = $character[2][0]
	    = $character[2][3] = $character[2][4] = $character[3][3]
	    = $character[4][1] = $character[4][2] = $character[4][4] = "_";
	$character[1][8] = $character[2][7] = $character[3][0] = $character[3][2]
	    = $character[3][4] = $character[3][6] = $character[4][5] = "\/";
	$character[4][0] = "\\";
	return \@character;
};

function character_e => sub {
	my @character = $_[0]->default_character(6);
	$character[2][5] = $character[4][0] = "\\";
	$character[1][0] = $character[1][1] = $character[1][2] = $character[1][3]
	    = $character[1][4] = $character[2][0] = $character[2][3]
	    = $character[3][3] = $character[3][4] = $character[4][1]
	    = $character[4][2] = $character[4][3] = "_";
	$character[3][0] = $character[3][5] = $character[4][4] = "\/";
	return \@character;
};

function character_f => sub {
	my @character = $_[0]->default_character(8);
	$character[1][7] = $character[2][4] = $character[3][5] = $character[4][0]
	    = $character[4][2] = "\/";
	$character[0][0] = $character[0][1] = $character[0][2] = $character[0][3]
	    = $character[0][4] = $character[0][5] = $character[0][6]
	    = $character[0][7] = $character[1][0] = $character[1][1]
	    = $character[1][2] = $character[1][5] = $character[1][6]
	    = $character[2][0] = $character[2][1] = $character[2][5]
	    = $character[3][0] = $character[3][3] = $character[3][4]
	    = $character[4][1] = "_";
	return \@character;
};

function character_g => sub {
	my @character = $_[0]->default_character(9);
	$character[2][7] = "\`";
	$character[4][1] = "\\";
	$character[2][8] = $character[3][3] = $character[3][5] = $character[3][7]
	    = $character[4][6] = $character[5][0] = $character[5][5] = "\/";
	$character[1][0] = $character[1][1] = $character[1][2] = $character[1][3]
	    = $character[1][4] = $character[1][5] = $character[1][6]
	    = $character[1][8] = $character[2][0] = $character[2][1]
	    = $character[2][4] = $character[2][5] = $character[3][0]
	    = $character[3][4] = $character[4][0] = $character[4][2]
	    = $character[4][3] = $character[5][1] = $character[5][2]
	    = $character[5][3] = $character[5][4] = "_";
	$character[4][4] = "\,";
	return \@character;
};

function character_h => sub {
	my @character = $_[0]->default_character(8);
	$character[2][7] = "\\";
	$character[0][0] = $character[0][1] = $character[0][2] = $character[0][3]
	    = $character[0][4] = $character[0][5] = $character[1][0]
	    = $character[1][1] = $character[1][2] = $character[1][6]
	    = $character[2][0] = $character[2][1] = $character[2][4]
	    = $character[2][5] = $character[3][0] = $character[4][1]
	    = $character[4][5] = "_";
	$character[1][5] = $character[3][3] = $character[3][5] = $character[3][7]
	    = $character[4][0] = $character[4][2] = $character[4][4]
	    = $character[4][6] = "\/";
	return \@character;
};

function character_i => sub {
	my @character = $_[0]->default_character(6);
	$character[1][3] = "\(";
	$character[1][5] = "\)";
	$character[0][0] = $character[0][1] = $character[0][2] = $character[0][3]
	    = $character[0][4] = $character[1][0] = $character[1][1]
	    = $character[1][2] = $character[1][4] = $character[2][0]
	    = $character[2][1] = $character[3][0] = $character[4][1] = "_";
	$character[2][4] = $character[3][3] = $character[4][0] = $character[4][2]
	    = "\/";
	return \@character;
};

function character_j => sub {
	my @character = $_[0]->default_character(9);
	$character[1][6] = "\(";
	$character[2][7] = $character[3][6] = $character[4][5] = $character[5][0]
	    = $character[5][4] = "\/";
	$character[0][0] = $character[0][1] = $character[0][2] = $character[0][3]
	    = $character[0][4] = $character[0][5] = $character[0][6]
	    = $character[0][7] = $character[1][0] = $character[1][1]
	    = $character[1][2] = $character[1][3] = $character[1][4]
	    = $character[1][5] = $character[1][7] = $character[2][0]
	    = $character[2][1] = $character[2][2] = $character[2][3]
	    = $character[2][4] = $character[3][0] = $character[3][1]
	    = $character[3][2] = $character[3][3] = $character[4][0]
	    = $character[4][1] = $character[4][2] = $character[5][1]
	    = $character[5][2] = $character[5][3] = "_";
	$character[1][8] = "\)";
	return \@character;
};

function character_k => sub {
	my @character = $_[0]->default_character(8);
	$character[3][4] = "\<";
	$character[4][3] = $character[4][5] = "\|";
	$character[3][3] = "\,";
	$character[0][0] = $character[0][1] = $character[0][2] = $character[0][3]
	    = $character[0][4] = $character[0][5] = $character[1][0]
	    = $character[1][1] = $character[1][2] = $character[1][6]
	    = $character[1][7] = $character[2][0] = $character[2][1]
	    = $character[2][6] = $character[3][0] = $character[4][1]
	    = $character[4][4] = "_";
	$character[1][5] = $character[2][4] = $character[2][5] = $character[2][7]
	    = $character[4][0] = $character[4][2] = "\/";
	return \@character;
};

function character_l => sub {
	my @character = $_[0]->default_character(6);
	$character[0][0] = $character[0][1] = $character[0][2] = $character[0][3]
	    = $character[0][4] = $character[0][5] = $character[1][0]
	    = $character[1][1] = $character[1][2] = $character[2][0]
	    = $character[2][1] = $character[3][0] = $character[4][1] = "_";
	$character[1][5] = $character[2][4] = $character[3][3] = $character[4][0]
	    = $character[4][2] = "\/";
	return \@character;
};

function character_m => sub {
	my @character = $_[0]->default_character(12);
	$character[3][3] = $character[3][5] = $character[3][7] = $character[3][9]
	    = $character[3][11] = $character[4][0] = $character[4][2]
	    = $character[4][4]  = $character[4][6] = $character[4][8]
	    = $character[4][10] = "\/";
	$character[1][0] = $character[1][1] = $character[1][2] = $character[1][3]
	    = $character[1][4] = $character[1][5] = $character[1][6]
	    = $character[1][8] = $character[1][9] = $character[1][10]
	    = $character[2][0] = $character[2][1] = $character[2][4]
	    = $character[2][5] = $character[2][8] = $character[2][9]
	    = $character[3][0] = $character[4][1] = $character[4][5]
	    = $character[4][9] = "_";
	$character[2][11] = "\\";
	$character[2][7]  = "\`";
	return \@character;
};

function character_n => sub {
	my @character = $_[0]->default_character(8);
	$character[1][0] = $character[1][1] = $character[1][2] = $character[1][3]
	    = $character[1][4] = $character[1][5] = $character[1][6]
	    = $character[2][0] = $character[2][1] = $character[2][4]
	    = $character[2][5] = $character[3][0] = $character[4][1]
	    = $character[4][5] = "_";
	$character[3][3] = $character[3][5] = $character[3][7] = $character[4][0]
	    = $character[4][2] = $character[4][4] = $character[4][6] = "\/";
	$character[2][7] = "\\";
	return \@character;
};

function character_o => sub {
	my @character = $_[0]->default_character(7);
	$character[1][0] = $character[1][1] = $character[1][2] = $character[1][3]
	    = $character[1][4] = $character[1][5] = $character[2][0]
	    = $character[2][3] = $character[2][4] = $character[3][3]
	    = $character[4][1] = $character[4][2] = $character[4][3]
	    = $character[4][4] = "_";
	$character[3][0] = $character[3][2] = $character[3][4] = $character[3][6]
	    = $character[4][5] = "\/";
	$character[2][6] = $character[4][0] = "\\";
	return \@character;
};

function character_p => sub {
	my @character = $_[0]->default_character(9);
	$character[2][8] = "\\";
	$character[3][4] = $character[3][6] = $character[3][8] = $character[4][7]
	    = $character[5][0] = $character[5][2] = "\/";
	$character[4][3] = "\.";
	$character[1][0] = $character[1][1] = $character[1][2] = $character[1][3]
	    = $character[1][4] = $character[1][5] = $character[1][6]
	    = $character[1][7] = $character[2][0] = $character[2][1]
	    = $character[2][2] = $character[2][5] = $character[2][6]
	    = $character[3][0] = $character[3][1] = $character[3][5]
	    = $character[4][0] = $character[4][4] = $character[4][5]
	    = $character[4][6] = $character[5][1] = "_";
	return \@character;
};

function character_q => sub {
	my @character = $_[0]->default_character(8);
	$character[2][6] = "\`";
	$character[4][0] = "\\";
	$character[4][3] = "\,";
	$character[1][0] = $character[1][1] = $character[1][2] = $character[1][3]
	    = $character[1][4] = $character[1][5] = $character[1][7]
	    = $character[2][0] = $character[2][3] = $character[2][4]
	    = $character[3][3] = $character[4][1] = $character[4][2]
	    = $character[5][3] = "_";
	$character[2][7] = $character[3][0] = $character[3][2] = $character[3][4]
	    = $character[3][6] = $character[4][5] = $character[5][2]
	    = $character[5][4] = "\/";
	return \@character;
};

function character_r => sub {
	my @character = $_[0]->default_character(8);
	$character[1][0] = $character[1][1] = $character[1][2] = $character[1][3]
	    = $character[1][4] = $character[1][5] = $character[1][6]
	    = $character[1][7] = $character[2][0] = $character[2][1]
	    = $character[2][4] = $character[2][5] = $character[2][6]
	    = $character[3][0] = $character[4][1] = "_";
	$character[2][7] = $character[3][3] = $character[4][0] = $character[4][2]
	    = "\/";
	return \@character;
};

function character_s => sub {
	my @character = $_[0]->default_character(8);
	$character[3][6] = "\)";
	$character[1][0] = $character[1][1] = $character[1][2] = $character[1][3]
	    = $character[1][4] = $character[1][5] = $character[1][6]
	    = $character[1][7] = $character[2][0] = $character[2][1]
	    = $character[2][4] = $character[2][5] = $character[2][6]
	    = $character[3][0] = $character[3][2] = $character[3][3]
	    = $character[4][1] = $character[4][2] = $character[4][3]
	    = $character[4][4] = "_";
	$character[2][7] = $character[4][0] = $character[4][5] = "\/";
	$character[3][1] = "\(";
	return \@character;
};

function character_t => sub {
	my @character = $_[0]->default_character(6);
	$character[1][4] = $character[2][5] = $character[3][0] = $character[3][2]
	    = $character[4][3] = "\/";
	$character[0][0] = $character[0][1] = $character[0][2] = $character[0][3]
	    = $character[0][4] = $character[1][0] = $character[1][1]
	    = $character[1][5] = $character[2][0] = $character[2][3]
	    = $character[2][4] = $character[3][3] = $character[4][1]
	    = $character[4][2] = "_";
	$character[4][0] = "\\";
	return \@character;
};

function character_u => sub {
	my @character = $_[0]->default_character(8);
	$character[4][3] = "\,";
	$character[1][0] = $character[1][1] = $character[1][2] = $character[1][3]
	    = $character[1][6] = $character[1][7] = $character[2][0]
	    = $character[3][3] = $character[4][1] = $character[4][2]
	    = $character[4][4] = "_";
	$character[2][3] = $character[2][5] = $character[2][7] = $character[3][0]
	    = $character[3][2] = $character[3][4] = $character[3][6]
	    = $character[4][5] = "\/";
	$character[4][0] = "\\";
	return \@character;
};

function character_v => sub {
	my @character = $_[0]->default_character(8);
	$character[2][3] = $character[3][3] = "\|";
	$character[1][0] = $character[1][1] = $character[1][2] = $character[1][6]
	    = $character[1][7] = $character[2][0] = $character[2][1]
	    = $character[3][0] = $character[3][1] = $character[4][0]
	    = $character[4][1] = $character[4][2] = $character[4][3]
	    = $character[4][4] = "_";
	$character[2][5] = $character[2][7] = $character[3][4] = $character[3][6]
	    = $character[4][5] = "\/";
	return \@character;
};

function character_w => sub {
	my @character = $_[0]->default_character(11);
	$character[2][3] = $character[2][6] = $character[3][3] = $character[3][6]
	    = $character[4][5] = "\|";
	$character[1][0] = $character[1][1] = $character[1][2] = $character[1][9]
	    = $character[1][10] = $character[2][0] = $character[2][1]
	    = $character[3][0]  = $character[3][1] = $character[4][0]
	    = $character[4][1]  = $character[4][2] = $character[4][3]
	    = $character[4][6]  = $character[4][7] = "_";
	$character[2][5] = $character[2][8] = $character[2][10]
	    = $character[3][4] = $character[3][7] = $character[3][9]
	    = $character[4][4] = $character[4][8] = "\/";
	return \@character;
};

function character_x => sub {
	my @character = $_[0]->default_character(8);
	$character[1][0] = $character[1][1] = $character[1][2] = $character[1][3]
	    = $character[1][6] = $character[1][7] = $character[2][0]
	    = $character[2][1] = $character[2][6] = $character[3][0]
	    = $character[3][1] = $character[4][1] = $character[4][4] = "_";
	$character[2][5] = $character[2][7] = $character[4][0] = $character[4][2]
	    = "\/";
	$character[3][5] = "\<";
	$character[3][2] = "\>";
	$character[2][4] = $character[4][3] = $character[4][5] = "\|";
	return \@character;
};

function character_y => sub {
	my @character = $_[0]->default_character(9);
	$character[4][4] = "\,";
	$character[1][0] = $character[1][1] = $character[1][2] = $character[1][3]
	    = $character[1][4] = $character[1][7] = $character[1][8]
	    = $character[2][0] = $character[2][1] = $character[3][0]
	    = $character[3][4] = $character[4][0] = $character[4][2]
	    = $character[4][3] = $character[5][1] = $character[5][2]
	    = $character[5][3] = $character[5][4] = "_";
	$character[2][4] = $character[2][6] = $character[2][8] = $character[3][3]
	    = $character[3][5] = $character[3][7] = $character[4][6]
	    = $character[5][0] = $character[5][5] = "\/";
	$character[4][1] = "\\";
	return \@character;
};

function character_z => sub {
	my @character = $_[0]->default_character(6);
	$character[1][0] = $character[1][1] = $character[1][2] = $character[1][3]
	    = $character[1][4] = $character[1][5] = $character[2][0]
	    = $character[2][1] = $character[2][2] = $character[3][0]
	    = $character[3][1] = $character[3][5] = $character[4][0]
	    = $character[4][1] = $character[4][2] = $character[4][3]
	    = $character[4][4] = "_";
	$character[2][5] = $character[3][4] = $character[4][5] = "\/";
	return \@character;
};

function character_0 => sub {
	my @character = $_[0]->default_character(8);
	$character[1][7] = $character[4][0] = "\\";
	$character[2][3] = $character[2][5] = $character[2][7] = $character[3][0]
	    = $character[3][2] = $character[3][4] = $character[3][6]
	    = $character[4][5] = "\/";
	$character[0][0] = $character[0][1] = $character[0][2] = $character[0][3]
	    = $character[0][4] = $character[0][5] = $character[0][6]
	    = $character[1][0] = $character[1][1] = $character[1][4]
	    = $character[1][5] = $character[2][0] = $character[3][3]
	    = $character[4][1] = $character[4][2] = $character[4][3]
	    = $character[4][4] = "_";
	return \@character;
};

function character_1 => sub {
	my @character = $_[0]->default_character(6);
	$character[0][0] = $character[0][1] = $character[0][2] = $character[0][3]
	    = $character[0][4] = $character[0][5] = $character[1][0]
	    = $character[1][1] = $character[2][0] = $character[2][1]
	    = $character[3][0] = $character[4][1] = "_";
	$character[1][5] = $character[2][4] = $character[3][3] = $character[4][0]
	    = $character[4][2] = "\/";
	$character[1][2] = "\<";
	return \@character;
};

function character_2 => sub {
	my @character = $_[0]->default_character(7);
	$character[0][0] = $character[0][1] = $character[0][2] = $character[0][3]
	    = $character[0][4] = $character[0][5] = $character[1][0]
	    = $character[1][1] = $character[1][3] = $character[1][4]
	    = $character[2][0] = $character[2][1] = $character[2][2]
	    = $character[2][3] = $character[3][0] = $character[3][3]
	    = $character[3][4] = $character[4][1] = $character[4][2]
	    = $character[4][3] = $character[4][4] = "_";
	$character[2][4] = $character[2][6] = $character[3][5] = $character[4][0]
	    = $character[4][5] = "\/";
	$character[1][2] = "\|";
	$character[1][6] = "\\";
	return \@character;
};

function character_3 => sub {
	my @character = $_[0]->default_character(8);
	$character[2][6] = "\<";
	$character[1][2] = "\|";
	$character[0][0] = $character[0][1] = $character[0][2] = $character[0][3]
	    = $character[0][4] = $character[0][5] = $character[0][6]
	    = $character[0][7] = $character[1][0] = $character[1][1]
	    = $character[1][3] = $character[1][4] = $character[2][0]
	    = $character[2][1] = $character[2][2] = $character[2][4]
	    = $character[3][0] = $character[3][1] = $character[3][2]
	    = $character[3][3] = $character[4][1] = $character[4][2]
	    = $character[4][3] = $character[4][4] = "_";
	$character[1][7] = $character[2][3] = $character[3][4] = $character[3][6]
	    = $character[4][0] = $character[4][5] = "\/";
	return \@character;
};

function character_4 => sub {
	my @character = $_[0]->default_character(8);
	$character[0][0] = $character[0][1] = $character[0][2] = $character[0][3]
	    = $character[0][4] = $character[0][6] = $character[0][7]
	    = $character[1][0] = $character[1][1] = $character[2][0]
	    = $character[2][7] = $character[3][1] = $character[3][2]
	    = $character[3][5] = $character[3][6] = $character[4][3] = "_";
	$character[1][4] = $character[1][5] = $character[1][7] = $character[2][3]
	    = $character[2][4] = $character[2][6] = $character[3][0]
	    = $character[3][7] = $character[4][2] = $character[4][4] = "\/";
	return \@character;
};

function character_5 => sub {
	my @character = $_[0]->default_character(10);
	$character[1][9] = $character[3][5] = $character[3][7] = $character[4][0]
	    = $character[4][6] = "\/";
	$character[0][0] = $character[0][1] = $character[0][2] = $character[0][3]
	    = $character[0][4] = $character[0][5] = $character[0][6]
	    = $character[0][7] = $character[0][8] = $character[0][9]
	    = $character[1][0] = $character[1][1] = $character[1][2]
	    = $character[1][5] = $character[1][6] = $character[1][7]
	    = $character[1][8] = $character[2][0] = $character[2][1]
	    = $character[2][2] = $character[2][3] = $character[2][4]
	    = $character[2][5] = $character[3][1] = $character[3][2]
	    = $character[3][3] = $character[3][4] = $character[4][1]
	    = $character[4][2] = $character[4][3] = $character[4][4]
	    = $character[4][5] = "_";
	$character[2][7] = "\\";
	return \@character;
};

function character_6 => sub {
	my @character = $_[0]->default_character(8);
	$character[2][6] = $character[4][0] = "\\";
	$character[1][7] = $character[3][0] = $character[3][2] = $character[3][4]
	    = $character[3][6] = $character[4][5] = "\/";
	$character[0][0] = $character[0][1] = $character[0][2] = $character[0][3]
	    = $character[0][4] = $character[0][5] = $character[0][6]
	    = $character[0][7] = $character[1][0] = $character[1][1]
	    = $character[1][4] = $character[1][5] = $character[1][6]
	    = $character[2][0] = $character[2][3] = $character[2][4]
	    = $character[3][3] = $character[4][1] = $character[4][2]
	    = $character[4][3] = $character[4][4] = "_";
	return \@character;
};

function character_7 => sub {
	my @character = $_[0]->default_character(6);
	$character[0][0] = $character[0][1] = $character[0][2] = $character[0][3]
	    = $character[0][4] = $character[0][5] = $character[1][1]
	    = $character[1][2] = $character[2][0] = $character[2][1]
	    = $character[3][0] = $character[4][1] = "_";
	$character[1][0] = $character[1][5] = $character[2][4] = $character[3][3]
	    = $character[4][0] = $character[4][2] = "\/";
	return \@character;
};

function character_8 => sub {
	my @character = $_[0]->default_character(8);
	$character[4][0] = "\\";
	$character[1][2] = "\(";
	$character[2][7] = "\|";
	$character[0][0] = $character[0][1] = $character[0][2] = $character[0][3]
	    = $character[0][4] = $character[0][5] = $character[0][6]
	    = $character[1][0] = $character[1][1] = $character[1][4]
	    = $character[1][5] = $character[2][0] = $character[2][3]
	    = $character[2][4] = $character[3][3] = $character[4][1]
	    = $character[4][2] = $character[4][3] = $character[4][4] = "_";
	$character[1][7] = "\)";
	$character[3][0] = $character[3][2] = $character[3][4] = $character[3][6]
	    = $character[4][5] = "\/";
	return \@character;
};

function character_9 => sub {
	my @character = $_[0]->default_character(8);
	$character[1][7] = $character[3][1] = "\\";
	$character[2][3] = $character[2][5] = $character[2][7] = $character[3][6]
	    = $character[4][0] = $character[4][5] = "\/";
	$character[0][0] = $character[0][1] = $character[0][2] = $character[0][3]
	    = $character[0][4] = $character[0][5] = $character[0][6]
	    = $character[1][0] = $character[1][1] = $character[1][4]
	    = $character[1][5] = $character[2][0] = $character[2][4]
	    = $character[3][0] = $character[3][2] = $character[3][3]
	    = $character[4][1] = $character[4][2] = $character[4][3]
	    = $character[4][4] = "_";
	$character[3][4] = "\,";
	return \@character;
};

1;

__END__

=head1 NAME

Ascii::Text::Font::Speed - Speed Font

=head1 VERSION

Version 0.21

=cut

=head1 SYNOPSIS

Quick summary of what the module does.

	use Ascii::Text::Font::Speed;

	my $foo = Ascii::Text::Font::Speed->new();

	...

=head1 EXTENDS

=head2 Ascii::Text::Font

=head1 SUBROUTINES/METHODS

=head2 space

=head2 character_A

	_______ 
	___    |
	__  /| |
	_  ___ |
	/_/  |_|
	        

=head2 character_B

	________ 
	___  __ )
	__  __  |
	_  /_/ / 
	/_____/  
	         

=head2 character_C

	_________
	__  ____/
	_  /     
	/ /___   
	\____/   
	         

=head2 character_D

	________ 
	___  __ \
	__  / / /
	_  /_/ / 
	/_____/  
	         

=head2 character_E

	__________
	___  ____/
	__  __/   
	_  /___   
	/_____/   
	          

=head2 character_F

	__________
	___  ____/
	__  /_    
	_  __/    
	/_/       
	          

=head2 character_G

	_________
	__  ____/
	_  / __  
	/ /_/ /  
	\____/   
	         

=head2 character_H

	______  __
	___  / / /
	__  /_/ / 
	_  __  /  
	/_/ /_/   
	          

=head2 character_I

	________
	____  _/
	 __  /  
	__/ /   
	/___/   
	        

=head2 character_J

	_________
	______  /
	___ _  / 
	/ /_/ /  
	\____/   
	         

=head2 character_K

	______ __
	___  //_/
	__  ,<   
	_  /| |  
	/_/ |_|  
	         

=head2 character_L

	______ 
	___  / 
	__  /  
	_  /___
	/_____/
	       

=head2 character_M

	______  ___
	___   |/  /
	__  /|_/ / 
	_  /  / /  
	/_/  /_/   
	           

=head2 character_N

	_____   __
	___  | / /
	__   |/ / 
	_  /|  /  
	/_/ |_/   
	          

=head2 character_O

	_______ 
	__  __ \
	_  / / /
	/ /_/ / 
	\____/  
	        

=head2 character_P

	________ 
	___  __ \
	__  /_/ /
	_  ____/ 
	/_/      
	         

=head2 character_Q

	_______ 
	__  __ \
	_  / / /
	/ /_/ / 
	\___\_\ 
	        

=head2 character_R

	________ 
	___  __ \
	__  /_/ /
	_  _, _/ 
	/_/ |_|  
	         

=head2 character_S

	________
	__  ___/
	_____ \ 
	____/ / 
	/____/  
	        

=head2 character_T

	________
	___  __/
	__  /   
	_  /    
	/_/     
	        

=head2 character_U

	_____  __
	__  / / /
	_  / / / 
	/ /_/ /  
	\____/   
	         

=head2 character_V

	___    __
	__ |  / /
	__ | / / 
	__ |/ /  
	_____/   
	         

=head2 character_W

	___       __
	__ |     / /
	__ | /| / / 
	__ |/ |/ /  
	____/|__/   
	            

=head2 character_X

	____  __
	__  |/ /
	__    / 
	_    |  
	/_/|_|  
	        

=head2 character_Y

	__  __
	_ \/ /
	__  / 
	_  /  
	/_/   
	      

=head2 character_Z

	______
	___  /
	__  / 
	_  /__
	/____/
	      

=head2 character_a

	        
	______ _
	_  __ `/
	/ /_/ / 
	\__,_/  
	        

=head2 character_b

	______  
	___  /_ 
	__  __ \
	_  /_/ /
	/_.___/ 
	        

=head2 character_c

	       
	_______
	_  ___/
	/ /__  
	\___/  
	       

=head2 character_d

	_________
	______  /
	_  __  / 
	/ /_/ /  
	\__,_/   
	         

=head2 character_e

	      
	_____ 
	_  _ \
	/  __/
	\___/ 
	      

=head2 character_f

	________
	___  __/
	__  /_  
	_  __/  
	/_/     
	        

=head2 character_g

	         
	_______ _
	__  __ `/
	_  /_/ / 
	_\__, /  
	/____/   

=head2 character_h

	______  
	___  /_ 
	__  __ \
	_  / / /
	/_/ /_/ 
	        

=head2 character_i

	_____ 
	___(_)
	__  / 
	_  /  
	/_/   
	      

=head2 character_j

	________ 
	______(_)
	_____  / 
	____  /  
	___  /   
	/___/    

=head2 character_k

	______  
	___  /__
	__  //_/
	_  ,<   
	/_/|_|  
	        

=head2 character_l

	______
	___  /
	__  / 
	_  /  
	/_/   
	      

=head2 character_m

	            
	_______ ___ 
	__  __ `__ \
	_  / / / / /
	/_/ /_/ /_/ 
	            

=head2 character_n

	        
	_______ 
	__  __ \
	_  / / /
	/_/ /_/ 
	        

=head2 character_o

	       
	______ 
	_  __ \
	/ /_/ /
	\____/ 
	       

=head2 character_p

	         
	________ 
	___  __ \
	__  /_/ /
	_  .___/ 
	/_/      

=head2 character_q

	        
	______ _
	_  __ `/
	/ /_/ / 
	\__, /  
	  /_/   

=head2 character_r

	        
	________
	__  ___/
	_  /    
	/_/     
	        

=head2 character_s

	        
	________
	__  ___/
	_(__  ) 
	/____/  
	        

=head2 character_t

	_____ 
	__  /_
	_  __/
	/ /_  
	\__/  
	      

=head2 character_u

	        
	____  __
	_  / / /
	/ /_/ / 
	\__,_/  
	        

=head2 character_v

	        
	___   __
	__ | / /
	__ |/ / 
	_____/  
	        

=head2 character_w

	           
	___      __
	__ | /| / /
	__ |/ |/ / 
	____/|__/  
	           

=head2 character_x

	        
	____  __
	__  |/_/
	__>  <  
	/_/|_|  
	        

=head2 character_y

	         
	_____  __
	__  / / /
	_  /_/ / 
	_\__, /  
	/____/   

=head2 character_z

	      
	______
	___  /
	__  /_
	_____/
	      

=head2 character_0

	_______ 
	__  __ \
	_  / / /
	/ /_/ / 
	\____/  
	        

=head2 character_1

	______
	__<  /
	__  / 
	_  /  
	/_/   
	      

=head2 character_2

	______ 
	__|__ \
	____/ /
	_  __/ 
	/____/ 
	       

=head2 character_3

	________
	__|__  /
	___/_ < 
	____/ / 
	/____/  
	        

=head2 character_4

	_____ __
	__  // /
	_  // /_
	/__  __/
	  /_/   
	        

=head2 character_5

	__________
	___  ____/
	______ \  
	 ____/ /  
	/_____/   
	          

=head2 character_6

	________
	__  ___/
	_  __ \ 
	/ /_/ / 
	\____/  
	        

=head2 character_7

	______
	/__  /
	__  / 
	_  /  
	/_/   
	      

=head2 character_8

	_______ 
	__( __ )
	_  __  |
	/ /_/ / 
	\____/  
	        

=head2 character_9

	_______ 
	__  __ \
	_  /_/ /
	_\__, / 
	/____/  
	        

=head1 PROPERTY

=head2 character_height



=head1 AUTHOR

AUTHOR, C<< <EMAIL> >>

=head1 BUGS

Please report any bugs or feature requests to C<bug-ascii::text::font::speed at rt.cpan.org>, or through
the web interface at L<https://rt.cpan.org/NoAuth/ReportBug.html?Queue=Ascii-Text-Font-Speed>.  I will be notified, and then you'll
automatically be notified of progress on your bug as I make changes.

=head1 SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc Ascii::Text::Font::Speed

You can also look for information at:

=over 4

=item * RT: CPAN's request tracker (report bugs here)

L<https://rt.cpan.org/NoAuth/Bugs.html?Dist=Ascii-Text-Font-Speed>

=item * AnnoCPAN: Annotated CPAN documentation

L<http://annocpan.org/dist/Ascii-Text-Font-Speed>

=item * CPAN Ratings

L<https://cpanratings.perl.org/d/Ascii-Text-Font-Speed>

=item * Search CPAN

L<https://metacpan.org/release/Ascii-Text-Font-Speed>

=back

=head1 ACKNOWLEDGEMENTS

=head1 LICENSE AND COPYRIGHT

This software is Copyright (c) 2020 by AUTHOR.

This is free software, licensed under:

  The Artistic License 2.0 (GPL Compatible)

=cut

 
